/*!
 * froala_editor v2.3.0 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2016 Froala Labs
 */

/**
 * Finnish
 */

$.FE.LANGUAGE['fi'] = {
  translation: {
    // Place holder
    "Type something": "Kirjoita jotain",

    // Basic formatting
    "Bold": "Lihavointi",
    "Italic": "Kursivointi",
    "Underline": "Alleviivaus",
    "Strikethrough": "Yliviivaus",

    // Main buttons
    "Insert": "Lis\u00e4\u00e4",
    "Delete": "Poista",
    "Cancel": "Peruuta",
    "OK": "Ok",
    "Back": "Takaisin",
    "Remove": "Poista",
    "More": "Lis\u00e4\u00e4",
    "Update": "P\u00e4ivitys",
    "Style": "Tyyli",

    // Font
    "Font Family": "Fontti",
    "Font Size": "Fonttikoko",

    // Colors
    "Colors": "V\u00e4rit",
    "Background": "Taustan",
    "Text": "Tekstin",

    // Paragraphs
    "Paragraph Format": "Muotoilut",
    "Normal": "Normaali",
    "Code": "Koodi",
    "Heading 1": "Otsikko 1",
    "Heading 2": "Otsikko 2",
    "Heading 3": "Otsikko 3",
    "Heading 4": "Otsikko 4",

    // Style
    "Paragraph Style": "Kappaleen tyyli",
    "Inline Style": "Linjassa tyyli",

    // Alignment
    "Align": "Tasaa",
    "Align Left": "Tasaa vasemmalle",
    "Align Center": "Keskit\u00e4",
    "Align Right": "Tasaa oikealle",
    "Align Justify": "Tasaa",
    "None": "Ei mit\u00e4\u00e4n",

    // Lists
    "Ordered List": "J\u00e4rjestetty lista",
    "Unordered List": "J\u00e4rjest\u00e4m\u00e4t\u00f6n lista",

    // Indent
    "Decrease Indent": "Sisenn\u00e4",
    "Increase Indent": "Loitonna",

    // Links
    "Insert Link": "Lis\u00e4\u00e4 linkki",
    "Open in new tab": "Avaa uudessa v\u00e4lilehdess\u00e4",
    "Open Link": "Avaa linkki",
    "Edit Link": "Muokkaa linkki",
    "Unlink": "Poista linkki",
    "Choose Link": "Valitse linkki",

    // Images
    "Insert Image": "Lis\u00e4\u00e4 kuva",
    "Upload Image": "Lataa kuva",
    "By URL": "Mukaan URL",
    "Browse": "Selailla",
    "Drop image": "Pudota kuva",
    "or click": "tai napsauta",
    "Manage Images": "Hallitse kuvia",
    "Loading": "Lastaus",
    "Deleting": "Poistaminen",
    "Tags": "Tagit",
    "Are you sure? Image will be deleted.": "Oletko varma? Kuva poistetaan.",
    "Replace": "Vaihda",
    "Uploading": "Lataaminen",
    "Loading image": "Lastaus kuva",
    "Display": "N\u00e4ytt\u00e4",
    "Inline": "Linjassa",
    "Break Text": "Rikkoa teksti",
    "Alternate Text": "Vaihtoehtoinen teksti",
    "Change Size": "Muuta kokoa",
    "Width": "Leveys",
    "Height": "Korkeus",
    "Something went wrong. Please try again.": "Jotain meni pieleen. Yrit\u00e4 uudelleen.",

    // Video
    "Insert Video": "Lis\u00e4\u00e4 video",
    "Embedded Code": "Upotettu koodi",

    // Tables
    "Insert Table": "Lis\u00e4\u00e4 taulukko",
    "Table Header": "Taulukko yl\u00e4tunniste",
    "Remove Table": "Poista taulukko",
    "Table Style": "Taulukko tyyli",
    "Horizontal Align": "Vaakasuora tasaa",
    "Row": "Rivi",
    "Insert row above": "Lis\u00e4\u00e4 rivi ennen",
    "Insert row below": "Lis\u00e4\u00e4 rivi j\u00e4lkeen",
    "Delete row": "Poista rivi",
    "Column": "Sarake",
    "Insert column before": "Lis\u00e4\u00e4 sarake ennen",
    "Insert column after": "Lis\u00e4\u00e4 sarake j\u00e4lkeen",
    "Delete column": "Poista sarake",
    "Cell": "Solu",
    "Merge cells": "Yhdist\u00e4 solut",
    "Horizontal split": "Jaa vaakasuora",
    "Vertical split": "Jaa pystysuora",
    "Cell Background": "Solun tausta",
    "Vertical Align": "Pystysuora tasaa",
    "Top": "Alku",
    "Middle": "Keskimm\u00e4inen",
    "Bottom": "Pohja",
    "Align Top": "Tasaa alkuun",
    "Align Middle": "Tasaa keskimm\u00e4inen",
    "Align Bottom": "Tasaa pohja",
    "Cell Style": "Solun tyyli",

    // Files
    "Upload File": "Lataa tiedosto",
    "Drop file": "Pudota tiedosto",

    // Emoticons
    "Emoticons": "Hymi\u00f6it\u00e4",
    "Grinning face": "Virnisteli kasvot",
    "Grinning face with smiling eyes": "Virnisteli kasvot hymyilev\u00e4t silm\u00e4t",
    "Face with tears of joy": "Kasvot ilon kyyneleit\u00e4",
    "Smiling face with open mouth": "Hymyilev\u00e4 kasvot suu auki",
    "Smiling face with open mouth and smiling eyes": "Hymyilev\u00e4 kasvot suu auki ja hymyilee silm\u00e4t",
    "Smiling face with open mouth and cold sweat": "Hymyilev\u00e4 kasvot suu auki ja kylm\u00e4 hiki",
    "Smiling face with open mouth and tightly-closed eyes": "Hymyilev\u00e4 kasvot suu auki ja tiiviisti suljettu silm\u00e4t",
    "Smiling face with halo": "Hymyilev\u00e4 kasvot Halo",
    "Smiling face with horns": "Hymyilev\u00e4 kasvot sarvet",
    "Winking face": "Silm\u00e4niskut kasvot",
    "Smiling face with smiling eyes": "Hymyilev\u00e4 kasvot hymyilev\u00e4t silm\u00e4t",
    "Face savoring delicious food": "Kasvot maistella herkullista ruokaa",
    "Relieved face": "Vapautettu kasvot",
    "Smiling face with heart-shaped eyes": "Hymyilev\u00e4t kasvot syd\u00e4men muotoinen silm\u00e4t",
    "Smiling face with sunglasses": "Hymyilev\u00e4 kasvot aurinkolasit",
    "Smirking face": "Hym\u00e4t\u00e4\u00e4 kasvot",
    "Neutral face": "Neutraali kasvot",
    "Expressionless face": "Ilmeet\u00f6n kasvot",
    "Unamused face": "Ei huvittanut kasvo",
    "Face with cold sweat": "Kasvot kylm\u00e4 hiki",
    "Pensive face": "Mietteli\u00e4s kasvot",
    "Confused face": "Sekava kasvot",
    "Confounded face": "Sekoitti kasvot",
    "Kissing face": "Suudella kasvot",
    "Face throwing a kiss": "Kasvo heitt\u00e4\u00e4 suudelma",
    "Kissing face with smiling eyes": "Suudella kasvot hymyilev\u00e4t silm\u00e4t",
    "Kissing face with closed eyes": "Suudella kasvot silm\u00e4t ummessa",
    "Face with stuck out tongue": "Kasvot ojensi kieli",
    "Face with stuck out tongue and winking eye": "Kasvot on juuttunut pois kielen ja silm\u00e4niskuja silm\u00e4",
    "Face with stuck out tongue and tightly-closed eyes": "Kasvot on juuttunut pois kielen ja tiiviisti suljettuna silm\u00e4t",
    "Disappointed face": "Pettynyt kasvot",
    "Worried face": "Huolissaan kasvot",
    "Angry face": "Vihainen kasvot",
    "Pouting face": "Pouting kasvot",
    "Crying face": "Itku kasvot",
    "Persevering face": "Pitk\u00e4j\u00e4nteinen kasvot",
    "Face with look of triumph": "Kasvot ilme Triumph",
    "Disappointed but relieved face": "Pettynyt mutta helpottunut kasvot",
    "Frowning face with open mouth": "Frowning kasvot suu auki",
    "Anguished face": "Tuskainen kasvot",
    "Fearful face": "Pelokkuus kasvot",
    "Weary face": "V\u00e4synyt kasvot",
    "Sleepy face": "Unelias kasvot",
    "Tired face": "V\u00e4synyt kasvot",
    "Grimacing face": "Irvist\u00e4en kasvot",
    "Loudly crying face": "\u00e4\u00e4nekk\u00e4\u00e4sti itku kasvot",
    "Face with open mouth": "Kasvot suu auki",
    "Hushed face": "Hiljentynyt kasvot",
    "Face with open mouth and cold sweat": "Kasvot suu auki ja kylm\u00e4 hiki",
    "Face screaming in fear": "Kasvot huutaa pelosta",
    "Astonished face": "H\u00e4mm\u00e4stynyt kasvot",
    "Flushed face": "Kasvojen punoitus",
    "Sleeping face": "Nukkuva kasvot",
    "Dizzy face": "Huimausta kasvot",
    "Face without mouth": "Kasvot ilman suuhun",
    "Face with medical mask": "Kasvot l\u00e4\u00e4ketieteen naamio",

    // Line breaker
    "Break": "Rikkoa",

    // Math
    "Subscript": "Alaindeksi",
    "Superscript": "Yl\u00e4indeksi",

    // Full screen
    "Fullscreen": "Koko n\u00e4ytt\u00f6",

    // Horizontal line
    "Insert Horizontal Line": "Lis\u00e4\u00e4 vaakasuora viiva",

    // Clear formatting
    "Clear Formatting": "Poista muotoilu",

    // Undo, redo
    "Undo": "Peru",
    "Redo": "Tee uudelleen",

    // Select all
    "Select All": "Valitse kaikki",

    // Code view
    "Code View": "Koodi n\u00e4kym\u00e4",

    // Quote
    "Quote": "Lainaus",
    "Increase": "Lis\u00e4t\u00e4",
    "Decrease": "Pienenn\u00e4",

    // Quick Insert
    "Quick Insert": "Nopea insertti"
  },
  direction: "ltr"
};
