/*!
 * froala_editor v2.3.0 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2016 Froala Labs
 */

/**
 * Hungarian
 */

$.FE.LANGUAGE['hu'] = {
  translation: {
    // Place holder
    "Type something": "T\u00edpus valami",

    // Basic formatting
    "Bold": "F\u00e9lk\u00f6v\u00e9r",
    "Italic": "D\u0151lt",
    "Underline": "Al\u00e1h\u00fazott",
    "Strikethrough": "\u00c1th\u00fazott",

    // Main buttons
    "Insert": "Beilleszt\u00e9se",
    "Delete": "T\u00f6r\u00f6l",
    "Cancel": "M\u00e9gse",
    "OK": "Rendben",
    "Back": "Vissza",
    "Remove": "Elt\u00e1vol\u00edt\u00e1sa",
    "More": "T\u00f6bb",
    "Update": "Friss\u00edt\u00e9s",
    "Style": "St\u00edlus",

    // Font
    "Font Family": "Bet\u0171t\u00edpus",
    "Font Size": "Bet\u0171m\u00e9retek",

    // Colors
    "Colors": "Sz\u00ednek",
    "Background": "H\u00e1tt\u00e9r",
    "Text": "Sz\u00f6veg",

    // Paragraphs
    "Paragraph Format": "Form\u00e1tumok",
    "Normal": "Norm\u00e1l",
    "Code": "K\u00f3d",
    "Heading 1": "C\u00edmsor 1",
    "Heading 2": "C\u00edmsor 2",
    "Heading 3": "C\u00edmsor 3",
    "Heading 4": "C\u00edmsor 4",

    // Style
    "Paragraph Style": "Bekezd\u00e9s st\u00edlus\u00e1t",
    "Inline Style": "Helyi st\u00edlus",

    // Alignment
    "Align": "Igaz\u00edt\u00e1s",
    "Align Left": "Balra igaz\u00edt",
    "Align Center": "K\u00f6z\u00e9pre z\u00e1r",
    "Align Right": "Jobbra igaz\u00edt",
    "Align Justify": "Sorkiz\u00e1r\u00e1s",
    "None": "Egyik sem",

    // Lists
    "Ordered List": "Sz\u00e1moz\u00e1s",
    "Unordered List": "Felsorol\u00e1s",

    // Indent
    "Decrease Indent": "Beh\u00faz\u00e1s cs\u00f6kkent\u00e9se",
    "Increase Indent": "Beh\u00faz\u00e1s n\u00f6vel\u00e9se",

    // Links
    "Insert Link": "Link beilleszt\u00e9se",
    "Open in new tab": "Megnyit\u00e1s \u00faj lapon",
    "Open Link": "Link megnyit\u00e1sa",
    "Edit Link": "Szerkeszt\u00e9s linkre",
    "Unlink": "Hivatkoz\u00e1s t\u00f6rl\u00e9se",
    "Choose Link": "V\u00e1lasztani linket",

    // Images
    "Insert Image": "K\u00e9p besz\u00far\u00e1sa",
    "Upload Image": "Felt\u00f6lt\u00e9s k\u00e9p",
    "By URL": "\u00c1ltal URL",
    "Browse": "B\u00f6ng\u00e9sszen",
    "Drop image": "Dobd k\u00e9p",
    "or click": "vagy kattintson",
    "Manage Images": "K\u00e9pek kezel\u00e9se",
    "Loading": "Terhel\u00e9s",
    "Deleting": "T\u00f6rl\u00e9se",
    "Tags": "C\u00edmk\u00e9k",
    "Are you sure? Image will be deleted.": "Biztos vagy benne? K\u00e9p t\u00f6rl\u00e9sre ker\u00fcl.",
    "Replace": "Cser\u00e9je",
    "Uploading": "Felt\u00f6lt\u00e9s",
    "Loading image": "K\u00e9pfelt\u00f6lt\u00e9s",
    "Display": "Kijelz\u0151",
    "Inline": "Sorban",
    "Break Text": "T\u00f6r sz\u00f6veg",
    "Alternate Text": "Alternat\u00edv sz\u00f6veget",
    "Change Size": "M\u00e9ret\u00e9nek v\u00e1ltoz\u00e1sa",
    "Width": "Sz\u00e9less\u00e9g",
    "Height": "Magass\u00e1g",
    "Something went wrong. Please try again.": "Valami elromlott. K\u00e9rlek pr\u00f3b\u00e1ld \u00fajra.",

    // Video
    "Insert Video": "Vide\u00f3 beilleszt\u00e9se",
    "Embedded Code": "Be\u00e1gyazott k\u00f3dot",

    // Tables
    "Insert Table": "T\u00e1bl\u00e1zat beilleszt\u00e9se",
    "Table Header": "T\u00e1bl\u00e1zat fejl\u00e9ce",
    "Remove Table": "T\u00e1bla elt\u00e1vol\u00edt\u00e1sa",
    "Table Style": "T\u00e1bl\u00e1zat st\u00edlus",
    "Horizontal Align": "V\u00edzszintes igaz\u00edt\u00e1s",
    "Row": "Sor",
    "Insert row above": "Sor besz\u00far\u00e1sa el\u00e9",
    "Insert row below": "Sor besz\u00far\u00e1sa m\u00f6g\u00e9",
    "Delete row": "Sor t\u00f6rl\u00e9se",
    "Column": "Oszlop",
    "Insert column before": "Oszlop besz\u00far\u00e1sa el\u00e9",
    "Insert column after": "Oszlop besz\u00far\u00e1sa m\u00f6g\u00e9",
    "Delete column": "Oszlop t\u00f6rl\u00e9se",
    "Cell": "Cella",
    "Merge cells": "Cell\u00e1k egyes\u00edt\u00e9se",
    "Horizontal split": "V\u00edzszintes osztott",
    "Vertical split": "F\u00fcgg\u0151leges osztott",
    "Cell Background": "Cella h\u00e1tt\u00e9r",
    "Vertical Align": "F\u00fcgg\u0151leges fej\u00e1ll\u00edt\u00e1s",
    "Top": "Fels\u0151",
    "Middle": "K\u00f6z\u00e9ps\u0151",
    "Bottom": "Als\u00f3",
    "Align Top": "Igaz\u00edtsa fels\u0151",
    "Align Middle": "Igaz\u00edtsa k\u00f6zep\u00e9n",
    "Align Bottom": "Igaz\u00edtsa alj\u00e1n",
    "Cell Style": "Cellast\u00edlust",

    // Files
    "Upload File": "F\u00e1jl felt\u00f6lt\u00e9se",
    "Drop file": "Csepp f\u00e1jl",

    // Emoticons
    "Emoticons": "Hangulatjelek",
    "Grinning face": "Vigyorg\u00f3",
    "Grinning face with smiling eyes": "Vigyorg\u00f3 arca mosolyg\u00f3 szemek",
    "Face with tears of joy": "Arc \u00e1t az \u00f6r\u00f6m k\u00f6nnyei",
    "Smiling face with open mouth": "Mosolyg\u00f3 arc t\u00e1tott sz\u00e1jjal",
    "Smiling face with open mouth and smiling eyes": "Mosolyg\u00f3 arc t\u00e1tott sz\u00e1jjal \u00e9s mosolyg\u00f3 szemek",
    "Smiling face with open mouth and cold sweat": "Mosolyg\u00f3 arc t\u00e1tott sz\u00e1jjal \u00e9s hideg ver\u00edt\u00e9k",
    "Smiling face with open mouth and tightly-closed eyes": "Mosolyg\u00f3 arc t\u00e1tott sz\u00e1jjal \u00e9s szorosan lehunyt szemmel",
    "Smiling face with halo": "Mosolyg\u00f3 arc halo",
    "Smiling face with horns": "Mosolyg\u00f3 arc szarvakkal",
    "Winking face": "Kacsintott arca",
    "Smiling face with smiling eyes": "Mosolyg\u00f3 arc mosolyg\u00f3 szemek",
    "Face savoring delicious food": "Arc \u00edzlelgette \u00edzletes \u00e9telek",
    "Relieved face": "Megk\u00f6nnyebb\u00fclt arccal",
    "Smiling face with heart-shaped eyes": "Mosolyg\u00f3 arc sz\u00edv alak\u00fa szemek",
    "Smiling face with sunglasses": "Mosolyg\u00f3 arc, napszem\u00fcveg",
    "Smirking face": "Vigyorg\u00f3 arca",
    "Neutral face": "Semleges arc",
    "Expressionless face": "Kifejez\u00e9stelen arc",
    "Unamused face": "Unott arc",
    "Face with cold sweat": "Arc\u00e1t hideg verejt\u00e9k",
    "Pensive face": "T\u00f6preng\u0151 arca",
    "Confused face": "Zavaros arca",
    "Confounded face": "R\u00e1c\u00e1folt arca",
    "Kissing face": "Cs\u00f3k arca",
    "Face throwing a kiss": "Arc dobott egy cs\u00f3kot",
    "Kissing face with smiling eyes": "Cs\u00f3kos arc\u00e1t mosolyg\u00f3 szemek",
    "Kissing face with closed eyes": "Cs\u00f3kos arc\u00e1t csukott szemmel",
    "Face with stuck out tongue": "Szembe kiny\u00fajtotta a nyelv\u00e9t",
    "Face with stuck out tongue and winking eye": "Szembe kiny\u00fajtotta a nyelv\u00e9t, \u00e9s kacsintott szem",
    "Face with stuck out tongue and tightly-closed eyes": "Arc kiny\u00fajtotta a nyelv\u00e9t, \u00e9s szorosan lehunyt szemmel",
    "Disappointed face": "Csal\u00f3dott arca",
    "Worried face": "Agg\u00f3d\u00f3 arc\u00e1t",
    "Angry face": "D\u00fch\u00f6s arc",
    "Pouting face": "Duzzogva arc",
    "Crying face": "S\u00edr\u00f3 arc",
    "Persevering face": "Kitart\u00f3 arca",
    "Face with look of triumph": "Arc\u00e1t diadalmas pillant\u00e1st",
    "Disappointed but relieved face": "Csal\u00f3dott, de megk\u00f6nnyebb\u00fclt arccal",
    "Frowning face with open mouth": "Komor arcb\u00f3l t\u00e1tott sz\u00e1jjal",
    "Anguished face": "Gy\u00f6tr\u0151d\u0151 arca",
    "Fearful face": "F\u00e9lelmetes arc",
    "Weary face": "F\u00e1radt arca",
    "Sleepy face": "\u00e1lmos arc",
    "Tired face": "F\u00e1radt arca",
    "Grimacing face": "Fintorogva arc",
    "Loudly crying face": "Hangosan s\u00edr\u00f3 arc",
    "Face with open mouth": "Arc t\u00e1tott sz\u00e1jjal",
    "Hushed face": "Csit\u00edtotta arca",
    "Face with open mouth and cold sweat": "Arc t\u00e1tott sz\u00e1jjal \u00e9s hideg ver\u00edt\u00e9k",
    "Face screaming in fear": "Arc sikoltozva f\u00e9lelem",
    "Astonished face": "Meglepett arca",
    "Flushed face": "Kipirult arc",
    "Sleeping face": "Alv\u00f3 arc\u00e1t",
    "Dizzy face": "sz\u00e1d\u00fcl arca",
    "Face without mouth": "Arc n\u00e9lkül sz\u00e1j",
    "Face with medical mask": "Arc\u00e1t orvosi maszk",

    // Line breaker
    "Break": "T\u00f6r",

    // Math
    "Subscript": "Als\u00f3 index",
    "Superscript": "Fels\u0151 index",

    // Full screen
    "Fullscreen": "Teljes k\u00e9perny\u0151s",

    // Horizontal line
    "Insert Horizontal Line": "Helyezze v\u00edzszintes vonal",

    // Clear formatting
    "Clear Formatting": "Form\u00e1z\u00e1s elt\u00e1vol\u00edt\u00e1sa",

    // Undo, redo
    "Undo": "Visszavon\u00e1s",
    "Redo": "Ism\u00e9t",

    // Select all
    "Select All": "Minden kijel\u00f6l\u00e9se",

    // Code view
    "Code View": "K\u00f3d n\u00e9zet",

    // Quote
    "Quote": "Id\u00e9zet",
    "Increase": "N\u00f6veked\u00e9s",
    "Decrease": "Cs\u00f6kkent",

    // Quick Insert
    "Quick Insert": "Gyors bet\u00e9t"
  },
  direction: "ltr"
};
